@@ -943,6 +943,10 @@ class StrawberryPlugin(Plugin):
                 "strawberry.object_type.type",
                 "strawberry.federation.type",
                 "strawberry.federation.object_type.type",
+                "strawberry.federation.input",
+                "strawberry.federation.object_type.input",
+                "strawberry.federation.interface",
+                "strawberry.federation.object_type.interface",
                 "strawberry.schema_directive.schema_directive",
                 "strawberry.object_type.input",
                 "strawberry.object_type.interface",
